#ifndef NT2_INCLUDE_CONSTANTS_SQRTSMALLESTPOSVAL_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRTSMALLESTPOSVAL_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrtsmallestposval.hpp>

#endif
